
Development Philosophy
======================

Curver is an open but opinionated library, created by an open but opinionated developer.

Values
~~~~~~

Curver aims to be:

    1. Correct
    2. Understandable
    3. Fast

in that order.

Curver aims to follow `The Zen of Python <https://www.python.org/dev/peps/pep-0020/>`_, by Tim Peters.
In particular, that 'Simple is better than complex'.

Semantic Versioning
~~~~~~~~~~~~~~~~~~~

For many years, the open source community has been plagued with version number dystonia.
Numbers vary so greatly from project to project, they are practically meaningless.

Requests uses `Semantic Versioning <http://semver.org>`_.
This specification seeks to put an end to this madness with a small set of practical guidelines for you and your colleagues to use in your next project.
